@@ -2,11 +2,52 @@ package Clustericious;
 
 use strict;
 use warnings;
+use 5.010;
+use File::Spec;
+use File::HomeDir;
 
 # ABSTRACT: A framework for RESTful processing systems.
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
+sub _testing
+{
+  state $test = 0;
+  my($class, $new) = @_;
+  $test = $new if defined $new;
+  $test;
+}
+
+sub _config_path
+{
+  grep { -d $_ }
+    map { File::Spec->catdir(@$_) } 
+    grep { defined $_->[0] }
+    (
+      [ $ENV{CLUSTERICIOUS_CONF_DIR} ],
+      (!_testing) ? (
+        [ File::HomeDir->my_home, 'etc' ],
+        [ File::HomeDir->my_dist_config('Clustericious') ],
+        [ '', 'etc' ],
+      ) : (),
+    );
+}
+
+sub _slurp_pid ($)
+{
+  use autodie;
+  my($fn) = @_;
+  open my $fh, '<', $fn;
+  my $pid = <$fh>;
+  close $fh;
+  chomp $pid;
+  $pid;
+}
+
+# Note sub _config_uncache also gets placed
+# in this package, but it is defined in
+# Clustericious::Config.
+
 1;
 
 __END__
@@ -21,7 +62,7 @@ Clustericious - A framework for RESTful processing systems.
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
