@@ -3,17 +3,10 @@ package Clustericious::Client;
 use strict;
 use warnings;
 use 5.010;
-
-# ABSTRACT: Construct command line and perl clients for RESTful services.
-our $VERSION = '1.04'; # VERSION
-
-
 use Mojo::Base qw/-base/;
-
 use Mojo::UserAgent;
 use Mojo::ByteStream qw/b/;
 use Mojo::Parameters;
-use JSON::XS;
 use Clustericious::Config;
 use Clustericious::Client::Object;
 use Clustericious::Client::Meta;
@@ -21,6 +14,10 @@ use Clustericious::Client::Meta::Route;
 use MojoX::Log::Log4perl;
 use Log::Log4perl qw/:easy/;
 use File::Temp;
+use JSON::MaybeXS qw( encode_json decode_json );
+
+# ABSTRACT: Construct command line and perl clients for RESTful services.
+our $VERSION = '1.05'; # VERSION
 
 
 has server_url => '';
@@ -517,7 +514,12 @@ sub _base_config {
     # Independent of remotes
     my $self = shift;
     return $self->{_base_config} if defined($self->{_base_config});
-    $self->{_base_config} = Clustericious::Config->new($self->_appname);
+    
+    my $config_name = ref $self;
+    $config_name =~ s/::Client$//;
+    $config_name =~ s/::/-/;
+    
+    $self->{_base_config} = Clustericious::Config->new($config_name);
     return $self->{_base_config};
 }
 
@@ -606,7 +608,7 @@ Clustericious::Client - Construct command line and perl clients for RESTful serv
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -674,8 +676,6 @@ From the command line :
 
 =head1 DESCRIPTION
 
-This is a beta release.  The API is subject to changes without notice.
-
 Clustericious::Client is library for construction clients for RESTful
 services.  It provides a mapping between command line arguments, method
 arguments, and URLs.
