@@ -8,16 +8,16 @@ use Clustericious::Config;
 use YAML::XS qw( Dump );
 
 # ABSTRACT: Debug a clustericious configuration file
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
 has description => <<EOT;
-print the various stages of the clustericious app configuration file
+Print the various stages of the clustericious app configuration file
 EOT
 
 has usage => <<EOT;
 usage $0: configdebug
-print the various stages of the clustericious app configuration file
+Print the various stages of the clustericious app configuration file
 EOT
 
 sub run
@@ -26,43 +26,38 @@ sub run
   my $app_name = $_[0] || ref($self->app);
 
   $ENV{MOJO_TEMPLATE_DEBUG} = 1;
-  $ENV{CLUSTERICIOUS_CONFIG_SAVE_RENDERED} = 1;
 
-  my $callback1 = sub
-  {
-    my($class, $src) = @_;
-    my $data;
-    if(ref $src)
+  my $config = Clustericious::Config->new($app_name, sub {
+    my $type = shift;
+    
+    if($type eq 'pre_rendered')
     {
-      say "[SCALAR :: template]";
-      $data = $$src;
+      my($src) = @_;
+      my $data;
+      if(ref $src)
+      {
+        say "[SCALAR :: template]";
+        $data = $$src;
+      }
+      else
+      {
+        say "[$src :: template]";
+        open my $fh, '<', $src;
+        local $/;
+        $data = <$fh>;
+        close $fh;
+      }
+      chomp $data;
+      say $data;
     }
-    else
+    elsif($type eq 'rendered')
     {
-      say "[$src :: template]";
-      open my $fh, '<', $src;
-      local $/;
-      $data = <$fh>;
-      close $fh;
+      my($file, $content) = @_;
+      say "[$file :: interpreted]";
+      chomp $content;
+      say $content;
     }
-    chomp $data;
-    say $data;
-  };
-
-  my $callback2 = sub
-  {
-    my($class, $file, $content) = @_;
-    say "[$file :: interpreted]";
-    chomp $content;
-    say $content;
-  };
-
-  # place the hooks in Clustericious::Config which usually
-  # doesn't do this debugging stuff.
-  do { no warnings; *Clustericious::Config::pre_rendered = $callback1; };
-  do { no warnings; *Clustericious::Config::rendered     = $callback2; };
-
-  my $config = Clustericious::Config->new($app_name);
+  });
 
   say "[merged]";
   print Dump({ %$config });
@@ -83,7 +78,7 @@ Clustericious::Command::configdebug - Debug a clustericious configuration file
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
