@@ -7,8 +7,7 @@ use Mojo::Base 'Clustericious::Command';
 use Clustericious;
 
 # ABSTRACT: Print the configuration path
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.05'; # VERSION
 
 
 has description => <<EOT;
@@ -21,7 +20,9 @@ EOT
 
 sub run
 {
-  my($self, @args) = @_;
+  my $self = shift;
+  my @args = @_ ? @_ : @ARGV;
+
   say for Clustericious->_config_path  
 }
 
@@ -39,7 +40,7 @@ Clustericious::Command::configpath - Print the configuration path
 
 =head1 VERSION
 
-version 1.28_01
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -63,8 +64,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
