@@ -7,7 +7,7 @@ use Mojo::Base 'Clustericious::Command';
 use Path::Class qw/dir/;
 
 # ABSTRACT: Generate a default configuration.
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
 has description => <<EOT;
@@ -61,7 +61,7 @@ Clustericious::Command::configure - Generate a default configuration.
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -83,7 +83,7 @@ Your app:
         files => { 'YourApp.conf' => <<<CUT }
  ---
  required_key   : default_value
- something_else : <%= $ENV{HOME} %>
+ something_else : <%= home %>
  CUT
    };
  }
