@@ -2,17 +2,17 @@ package Clustericious::Command::hypnotoad;
 
 use strict;
 use warnings;
+use Clustericious;
 use Clustericious::Log;
 use Clustericious::App;
 use Clustericious::Config;
 use Mojo::Server::Hypnotoad;
 use Data::Dumper;
-use Clustericious::Util qw( slurp_pid );
 use Cwd qw/getcwd abs_path/;
 use base 'Clustericious::Command';
 
 # ABSTRACT: Clustericious command to stat Hypnotoad
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
 __PACKAGE__->attr(description => "Start a hypnotad web server.\n");
@@ -54,7 +54,7 @@ sub run {
         local $ENV{HYPNOTOAD_CONFIG} = $sentinel;
         my $pid_file = $conf->{pid_file};
         if (-e $pid_file) {
-            chomp (my $pid = slurp_pid $pid_file);
+            chomp (my $pid = Clustericious::_slurp_pid $pid_file);
             if (!kill 0, $pid) {
                 WARN "removing old pid file $pid_file";
                 unlink $pid_file or WARN "Could not remove $pid_file : $!";
@@ -84,7 +84,7 @@ Clustericious::Command::hypnotoad - Clustericious command to stat Hypnotoad
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
