@@ -7,21 +7,22 @@ use Hash::Merge qw/merge/;
 use Data::Dumper;
 use Carp qw( croak );
 use base qw( Exporter );
-use JSON::XS qw( encode_json );
+use JSON::MaybeXS qw( encode_json );
+use Clustericious::Config;
 
 # ABSTRACT: Helpers for clustericious config files.
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
 our @mergeStack;
 our @EXPORT = qw( extends_config get_password home file dir hostname hostname_full json yaml address public_address interface );
 
 
-sub extends_config {
-    my $filename = shift;
-    my @args = @_;
-    push @mergeStack, Clustericious::Config->new($filename, \@args);
-    return '';
+sub extends_config
+{
+  my($name, @args) = @_;
+  push @mergeStack, Clustericious::Config->new($name, \@args);
+  return '';
 }
 
 #
@@ -32,24 +33,25 @@ sub extends_config {
 # directives.
 #
 sub _do_merges {
-    my $class = shift;
-    my $conf_data = shift; # Last one; Has highest precedence.
+  my($class, $data) = @_;
 
-    return $conf_data unless @mergeStack;
+  return $data unless @mergeStack;
 
-    # Nested extends_config's form a tree which we traverse depth first.
-    Hash::Merge::set_behavior( 'RIGHT_PRECEDENT' );
-    my %so_far = %{ shift @mergeStack };
-    while (my $c = shift @mergeStack) {
-        my %h = %$c;
-        %so_far = %{ merge( \%so_far, \%h ) };
-    }
-    %$conf_data = %{ merge( \%so_far, $conf_data ) };
+  # Nested extends_config's form a tree which we traverse depth first.
+  Hash::Merge::set_behavior( 'RIGHT_PRECEDENT' );
+  my %so_far = %{ shift @mergeStack };
+  while (my $c = shift @mergeStack)
+  {
+    my %h = %$c;
+    %so_far = %{ merge( \%so_far, \%h ) };
+  }
+  %$data = %{ merge( \%so_far, $data ) };
 }
 
 
-sub get_password {
-    return Clustericious::Config::Password->sentinel;
+sub get_password
+{
+  return Clustericious::Config::Callback::Password->new->to_yaml;
 }
 
 
@@ -175,7 +177,7 @@ Clustericious::Config::Helpers - Helpers for clustericious config files.
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
