@@ -6,14 +6,15 @@ use Mojo::Base 'Clustericious::App';
 use Clustericious::RouteBuilder qw/Clustericious::HelloWorld/;
 
 # ABSTRACT: Clustericious hello world application
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
-BEGIN {
-    $ENV{LOG_LEVEL} = 'FATAL';
-}
+get '/' => sub { shift->render_text('Hello, world') } => 'index';
 
-any '/*foo' => {foo => '', text => 'Clustericious is working!'};
+get '/modules' => sub {
+  my %copy = %INC;
+  shift->stash->{autodata} = \%copy;
+} => 'modules';
 
 1;
 
@@ -29,7 +30,7 @@ Clustericious::HelloWorld - Clustericious hello world application
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
