@@ -6,8 +6,7 @@ use Clustericious::Client;
 use Clustericious::Client::Command;
 
 # ABSTRACT: Clustericious hello world client
-our $VERSION = '1.28_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.05'; # VERSION
 
 route 'welcome' => "GET",  '/';
 
@@ -25,7 +24,7 @@ Clustericious::HelloWorld::Client - Clustericious hello world client
 
 =head1 VERSION
 
-version 1.28_01
+version 1.05
 
 =head1 AUTHOR
 
@@ -37,8 +36,6 @@ Contributors:
 
 Curt Tilmes
 
-Yanick Champoux
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by NASA GSFC.
