@@ -9,7 +9,7 @@ use File::ReadBackwards;
 use File::HomeDir;
 
 # ABSTRACT: A Log::Log4perl wrapper for use with Clustericious.
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
 sub import {
@@ -113,18 +113,18 @@ Clustericious::Log - A Log::Log4perl wrapper for use with Clustericious.
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
  use Clustericious::Log -init_logging => "appname";
-
+ 
  use Clustericious::Log;
  INFO "Hi there!";
 
 =head1 DESCRIPTION
 
-This is a simple wrapper around Log::Log4perl for use with
+This is a simple wrapper around L<Log::Log4perl> for use with
 Clustericious.  It handles initialization and exporting of
 convenient logging functions, and a default set of logging
 patterns.  It also makes the name of the application available
@@ -132,7 +132,7 @@ for logging patterns (see the example).
 
 =head1 EXAMPLE
 
-Here is a sample ~/etc/log4perl.conf :
+Here is a sample C<~/etc/log4perl.conf> :
 
  log4perl.rootLogger=TRACE, LOGFILE
  log4perl.appender.LOGFILE=Log::Log4perl::Appender::File
@@ -148,8 +148,8 @@ Here is a sample ~/etc/log4perl.conf :
 
 =item init_logging
 
-Start logging.  Looks for log4perl.conf or $app.log4perl.conf
-in ~/etc and /etc.
+Start logging.  Looks for C<log4perl.conf> or C<$app.log4perl.conf>
+in C<~/etc> and C</etc>.
 
 =item tail
 
@@ -167,10 +167,6 @@ The following variables affect logging :
  LOG_FILE
  MOJO_APP
 
-=head1 NOTES
-
-This is a beta release, the API may change without notice.
-
 =head1 SEE ALSO
 
 L<Log::Log4perl>, L<Clustericious>
