@@ -4,18 +4,18 @@ use strict;
 use warnings;
 use base 'Mojolicious::Plugin';
 use Mojo::ByteStream 'b';
-use JSON::XS;
+use JSON::MaybeXS;
 use YAML::XS qw/Dump Load/;
 use Clustericious::Log;
 
 # ABSTRACT: Handle data types automatically
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
 my $default_decode = 'application/x-www-form-urlencoded';
 my $default_encode = 'application/json';
 
-my $json_encoder = JSON::XS->new->allow_nonref->allow_blessed->convert_blessed;
+my $json_encoder = JSON::MaybeXS->new->allow_nonref->allow_blessed->convert_blessed;
 
 my %types =
 (
@@ -135,7 +135,7 @@ Clustericious::Plugin::AutodataHandler - Handle data types automatically
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
