@@ -6,7 +6,7 @@ use 5.010;
 use Log::Log4perl qw( :easy );
 
 # ABSTRACT: Route builder for Clustericious applications
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
 our %Routes;
@@ -189,7 +189,7 @@ Clustericious::RouteBuilder - Route builder for Clustericious applications
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -211,11 +211,7 @@ directly under your application's namespace (for example above MyApp's
 route module is MyApp::Routes).  The interface is reminiscent of 
 L<Mojolicious::Lite>, because it was forked from there some time ago.
 
-=head1 SUPER CLASS
-
-none
-
-=head1 METHODS
+=head1 FUNCTIONS
 
 =head2 any
 
