@@ -2,11 +2,12 @@ package Clustericious::RouteBuilder::Common;
 
 use strict;
 use warnings;
+use 5.010;
 use Clustericious::Log;
 use Sys::Hostname qw/hostname/;
 
-# ABSTRACT: Routes common to all clustericious apps.
-our $VERSION = '1.04'; # VERSION
+# ABSTRACT: Routes common to all clustericious applications
+our $VERSION = '1.05'; # VERSION
 
 
 sub _add_routes {
@@ -14,27 +15,27 @@ sub _add_routes {
     my $app = shift;
 
 
-    $app->routes->route('/version')->to(
+    $app->routes->get('/version')->to(
         cb => sub {
             my $self = shift;
-            $self->stash(autodata => [ $self->app->VERSION ]);
+            $self->stash(autodata => [ $self->app->VERSION // 'dev' ]);
         }
     );
 
 
-    $app->routes->route('/status')->to(
+    $app->routes->get('/status')->to(
         cb => sub {
             my $self = shift;
             my $app = ref $self->app || $self->app;
             $self->stash(autodata => { app_name => $app,
-                                     server_version => $self->app->VERSION,
+                                     server_version => $self->app->VERSION // 'dev',
                                      server_hostname => hostname(),
                                      server_url => $self->config->url(default => 'undef') });
         }
     );
 
 
-    $app->routes->route('/api')->to(
+    $app->routes->get('/api')->to(
         cb => sub {
             my $self = shift;
             $self->render( autodata => [ $self->app->dump_api() ] );
@@ -42,7 +43,7 @@ sub _add_routes {
     );
 
 
-    $app->routes->route('/api/:table')->to(
+    $app->routes->get('/api/:table')->to(
         cb => sub {
             my($self) = @_;
             my $table = $self->app->dump_api_table($self->stash('table'));
@@ -80,11 +81,11 @@ __END__
 
 =head1 NAME
 
-Clustericious::RouteBuilder::Common - Routes common to all clustericious apps.
+Clustericious::RouteBuilder::Common - Routes common to all clustericious applications
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 DESCRIPTION
 
