@@ -2,19 +2,17 @@ package Test::Clustericious;
 
 use strict;
 use warnings;
-
-# ABSTRACT: Test Clustericious apps
-our $VERSION = '1.04'; # VERSION
-
-
 use base 'Test::Mojo';
-
-use JSON::XS;
+use JSON::MaybeXS qw( encode_json decode_json );
 use YAML::XS;
 use Carp;
 use List::Util qw(first);
 use Clustericious::Config;
 
+# ABSTRACT: Test Clustericious applications
+our $VERSION = '1.05'; # VERSION
+
+
 require Test::More;
 
 
@@ -209,11 +207,11 @@ __END__
 
 =head1 NAME
 
-Test::Clustericious - Test Clustericious apps
+Test::Clustericious - Test Clustericious applications
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
