@@ -17,7 +17,7 @@ use YAML::XS qw( DumpFile );
 use File::Path qw( mkpath );
 use Clustericious::Config;
 use Mojo::Loader;
-
+use Clustericious;
 use base qw( Test::Builder::Module Exporter );
 
 our @EXPORT = qw( create_config_ok create_directory_ok home_directory_ok create_config_helper_ok );
@@ -32,13 +32,13 @@ sub _init
   mkdir $config_dir;
 
   $ENV{CLUSTERICIOUS_CONF_DIR} = $config_dir;
-  Clustericious::Config->_testing(1);
+  Clustericious->_testing(1);
 }
 
 BEGIN { _init() }
 
 # ABSTRACT: Test Clustericious::Config
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 
 sub create_config_ok ($;$$)
@@ -87,7 +87,7 @@ sub create_config_ok ($;$$)
   $test_name //= "create config for $config_name at $config_filename";
   
   # remove any cached copy if necessary
-  Clustericious::Config->_uncache($config_name);
+  Clustericious->_config_uncache($config_name);
 
   $tb->ok($ok, $test_name);
   return $config_filename;
@@ -157,7 +157,7 @@ Test::Clustericious::Config - Test Clustericious::Config
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
